=== modified file 'services/CMakeLists.txt'
--- services/CMakeLists.txt	2011-01-27 17:54:28 +0000
+++ services/CMakeLists.txt	2011-01-28 12:00:21 +0000
@@ -26,6 +26,8 @@
 add_executable(unity-panel-service
                panel-a11y.c
                panel-a11y.h
+               panel-indicator-accessible.c
+               panel-indicator-accessible.h
                panel-main.c
                panel-root-accessible.c
                panel-root-accessible.h

=== modified file 'services/panel-a11y.c'
--- services/panel-a11y.c	2011-01-27 17:54:28 +0000
+++ services/panel-a11y.c	2011-01-28 12:00:21 +0000
@@ -17,7 +17,6 @@
  * Authored by: Rodrigo Moya <rodrigo.moya@canonical.com>
  */
 
-#include <gio/gio.h>
 #include "panel-a11y.h"
 #include "panel-util-accessible.h"
 
@@ -29,7 +28,7 @@
 	if (!a11y_initialized)
 	  {
 			/* Load PanelUtilAccessible class */
-			g_type_class_unref (g_type_class_ref (PANEL_TYPE_UTIL_ACCESSIBLE));
+			g_type_class_ref (PANEL_TYPE_UTIL_ACCESSIBLE);
 			
 			a11y_initialized = TRUE;
 		}

=== added file 'services/panel-indicator-accessible.c'
--- services/panel-indicator-accessible.c	1970-01-01 00:00:00 +0000
+++ services/panel-indicator-accessible.c	2011-01-28 12:00:21 +0000
@@ -0,0 +1,97 @@
+// -*- Mode: C; tab-width:2; indent-tabs-mode: t; c-basic-offset: 2 -*-
+/*
+ * Copyright (C) 2011 Canonical Ltd
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 3 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authored by: Rodrigo Moya <rodrigo.moya@canonical.com>
+ */
+
+#include "panel-indicator-accessible.h"
+
+G_DEFINE_TYPE(PanelIndicatorAccessible, panel_indicator_accessible, ATK_TYPE_OBJECT)
+
+#define GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_INDICATOR_ACCESSIBLE, PanelIndicatorAccessiblePrivate))
+
+/* AtkObject methods */
+static void       panel_indicator_accessible_initialize     (AtkObject *accessible, gpointer data);
+static gint       panel_indicator_accessible_get_n_children (AtkObject *accessible);
+static AtkObject *panel_indicator_accessible_ref_child      (AtkObject *accessible, gint i);
+
+struct _PanelIndicatorAccessiblePrivate
+{
+};
+
+static void
+panel_indicator_accessible_class_init (PanelIndicatorAccessibleClass *klass)
+{
+	GObjectClass *object_class;
+	AtkObjectClass *atk_class;
+
+	/* GObject */
+	object_class = G_OBJECT_CLASS (klass);
+
+	/* AtkObject */
+	atk_class = ATK_OBJECT_CLASS (klass);
+	atk_class->initialize = panel_indicator_accessible_initialize;
+	atk_class->get_n_children = panel_indicator_accessible_get_n_children;
+	atk_class->ref_child = panel_indicator_accessible_ref_child;
+
+	g_type_class_add_private (object_class, sizeof (PanelIndicatorAccessiblePrivate));
+}
+
+static void
+panel_indicator_accessible_init (PanelIndicatorAccessible *pia)
+{
+	pia->priv = GET_PRIVATE (pia);
+}
+
+AtkObject *
+panel_indicator_accessible_new (void)
+{
+	AtkObject *accessible;
+
+	accessible = ATK_OBJECT (g_object_new (PANEL_TYPE_INDICATOR_ACCESSIBLE, NULL));
+
+	atk_object_initialize (accessible, NULL);
+
+	return accessible;
+}
+
+/* Implementation of AtkObject methods */
+
+static void
+panel_indicator_accessible_initialize (AtkObject *accessible, gpointer data)
+{
+	g_return_if_fail (PANEL_IS_INDICATOR_ACCESSIBLE (accessible));
+
+	atk_object_set_role (accessible, ATK_ROLE_LABEL);
+
+	ATK_OBJECT_CLASS (panel_indicator_accessible_parent_class)->initialize (accessible, data);
+}
+
+static gint
+panel_indicator_accessible_get_n_children (AtkObject *accessible)
+{
+	g_return_val_if_fail (PANEL_IS_INDICATOR_ACCESSIBLE (accessible), 0);
+
+	return 0;
+}
+
+static AtkObject *
+panel_indicator_accessible_ref_child (AtkObject *accessible, gint i)
+{
+	g_return_val_if_fail (PANEL_IS_INDICATOR_ACCESSIBLE (accessible), NULL);
+
+	return NULL;
+}

=== added file 'services/panel-indicator-accessible.h'
--- services/panel-indicator-accessible.h	1970-01-01 00:00:00 +0000
+++ services/panel-indicator-accessible.h	2011-01-28 12:00:21 +0000
@@ -0,0 +1,54 @@
+// -*- Mode: C; tab-width:2; indent-tabs-mode: t; c-basic-offset: 2 -*-
+/*
+ * Copyright (C) 2011 Canonical Ltd
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 3 as
+ * published by the Free Software Foundation.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authored by: Rodrigo Moya <rodrigo.moya@canonical.com>
+ */
+
+#ifndef _PANEL_INDICATOR_ACCESSIBLE_H_
+#define _PANEL_INDICATOR_ACCESSIBLE_H_
+
+#include <atk/atk.h>
+
+G_BEGIN_DECLS
+
+#define PANEL_TYPE_INDICATOR_ACCESSIBLE (panel_indicator_accessible_get_type ())
+#define PANEL_INDICATOR_ACCESSIBLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PANEL_TYPE_INDICATOR_ACCESSIBLE, PanelIndicatorAccessible))
+#define PANEL_INDICATOR_ACCESSIBLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PANEL_TYPE_INDICATOR_ACCESSIBLE, PanelIndicatorAccessibleClass))
+#define PANEL_IS_INDICATOR_ACCESSIBLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PANEL_TYPE_INDICATOR_ACCESSIBLE))
+#define PANEL_IS_INDICATOR_ACCESSIBLE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PANEL_TYPE_INDICATOR_ACCESSIBLE))
+#define PANEL_INDICATOR_ACCESSIBLE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PANEL_TYPE_INDICATOR_ACCESSIBLE, PanelIndicatorAccessibleClass))
+
+typedef struct _PanelIndicatorAccessible        PanelIndicatorAccessible;
+typedef struct _PanelIndicatorAccessibleClass   PanelIndicatorAccessibleClass;
+typedef struct _PanelIndicatorAccessiblePrivate PanelIndicatorAccessiblePrivate;
+
+struct _PanelIndicatorAccessible
+{
+	AtkObject                        parent;
+	PanelIndicatorAccessiblePrivate *priv;
+};
+
+struct _PanelIndicatorAccessibleClass
+{
+	AtkObjectClass parent_class;
+};
+
+GType      panel_indicator_accessible_get_type (void);
+AtkObject *panel_indicator_accessible_new (void);
+
+G_END_DECLS
+
+#endif

=== modified file 'services/panel-main.c'
--- services/panel-main.c	2011-01-27 17:54:28 +0000
+++ services/panel-main.c	2011-01-28 12:00:21 +0000
@@ -300,11 +300,12 @@
   guint         owner_id;
 
   g_unsetenv("UBUNTU_MENUPROXY");
-  g_setenv ("NO_AT_BRIDGE", "1", TRUE); /* Needed for A11Y */
+  g_unsetenv ("NO_AT_BRIDGE"); //, "1", TRUE);
+  g_unsetenv ("NO_GAIL");
 
   gtk_init (&argc, &argv);
-	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default(),
-	                                   INDICATORICONDIR);
+  gtk_icon_theme_append_search_path (gtk_icon_theme_get_default(),
+				     INDICATORICONDIR);
 
   panel_a11y_init ();
 

=== modified file 'services/panel-root-accessible.c'
--- services/panel-root-accessible.c	2011-01-27 17:54:28 +0000
+++ services/panel-root-accessible.c	2011-01-28 12:00:21 +0000
@@ -18,6 +18,7 @@
  */
 
 #include <glib/gi18n.h>
+#include "panel-indicator-accessible.h"
 #include "panel-root-accessible.h"
 #include "panel-service.h"
 
@@ -26,8 +27,7 @@
 #define GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PANEL_TYPE_ROOT_ACCESSIBLE, PanelRootAccessiblePrivate))
 
 /* AtkObject methods */
-static void       panel_root_accessible_initialize     (AtkObject *accessible,
-                                                        gpointer   data);
+static void       panel_root_accessible_initialize     (AtkObject *accessible, gpointer data);
 static gint       panel_root_accessible_get_n_children (AtkObject *accessible);
 static AtkObject *panel_root_accessible_ref_child      (AtkObject *accessible, gint i);
 static AtkObject *panel_root_accessible_get_parent     (AtkObject *accessible);
@@ -47,10 +47,10 @@
 
 	/* AtkObject */
 	atk_class = ATK_OBJECT_CLASS (klass);
+	atk_class->initialize = panel_root_accessible_initialize;
 	atk_class->get_n_children = panel_root_accessible_get_n_children;
   atk_class->ref_child = panel_root_accessible_ref_child;
   atk_class->get_parent = panel_root_accessible_get_parent;
-  atk_class->initialize = panel_root_accessible_initialize;
 
   g_type_class_add_private (object_class, sizeof (PanelRootAccessiblePrivate));
 }
@@ -100,7 +100,7 @@
 {
 	g_return_val_if_fail (PANEL_IS_ROOT_ACCESSIBLE (accessible), NULL);
 
-	return NULL; /* FIXME */
+	return panel_indicator_accessible_new (); /* FIXME */
 }
 
 static AtkObject *

=== modified file 'services/panel-root-accessible.h'
--- services/panel-root-accessible.h	2011-01-27 17:54:28 +0000
+++ services/panel-root-accessible.h	2011-01-28 12:00:21 +0000
@@ -25,7 +25,6 @@
 G_BEGIN_DECLS
 
 #define PANEL_TYPE_ROOT_ACCESSIBLE (panel_root_accessible_get_type ())
-
 #define PANEL_ROOT_ACCESSIBLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PANEL_TYPE_ROOT_ACCESSIBLE, PanelRootAccessible))
 #define PANEL_ROOT_ACCESSIBLE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PANEL_TYPE_ROOT_ACCESSIBLE, PanelRootAccessibleClass))
 #define PANEL_IS_ROOT_ACCESSIBLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PANEL_TYPE_ROOT_ACCESSIBLE))

=== modified file 'services/panel-util-accessible.c'
--- services/panel-util-accessible.c	2011-01-27 17:54:28 +0000
+++ services/panel-util-accessible.c	2011-01-28 12:00:21 +0000
@@ -32,11 +32,19 @@
 static void
 panel_util_accessible_class_init (PanelUtilAccessibleClass *klass)
 {
-	AtkUtilClass *atk_class;
+	AtkUtilClass *atk_class, *base_atk_class;
 
 	/* AtkUtil */
+	base_atk_class = g_type_class_peek (ATK_TYPE_UTIL);
+
 	atk_class = ATK_UTIL_CLASS (klass);
+	atk_class->add_global_event_listener = base_atk_class->add_global_event_listener;
+	atk_class->remove_global_event_listener = base_atk_class->remove_global_event_listener;
+	atk_class->add_key_event_listener = base_atk_class->add_key_event_listener;
+	atk_class->remove_key_event_listener = base_atk_class->remove_key_event_listener;
 	atk_class->get_root = panel_util_accessible_get_root;
+	atk_class->get_toolkit_name = base_atk_class->get_toolkit_name;
+	atk_class->get_toolkit_version = base_atk_class->get_toolkit_version;
 }
 
 static void

